A training abstraction for Keras models.

[![Build Status](https://travis-ci.org/triagemd/keras-trainer.svg?branch=master)](https://travis-ci.org/triagemd/keras-trainer) [![PyPI version](https://badge.fury.io/py/keras-trainer.svg)](https://badge.fury.io/py/keras-trainer)
